@@ -1,8 +1,5 @@
-(******************************************************************************)
-(* Lightweight thread library for OCaml
- * http://www.ocsigen.org/lwt
- * Interface Lwt_condition
- ******************************************************************************
+(* OCaml promise library
+ * https://ocsigen.org/lwt
  * Copyright (c) 2009, Metaweb Technologies, Inc.
  * All rights reserved.
  *
@@ -27,7 +24,7 @@
  * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
  * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
  * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- ******************************************************************************)
+ *)
 
 (** Conditions *)
 
@@ -48,7 +45,7 @@ val wait : ?mutex:Lwt_mutex.t -> 'a t -> 'a Lwt.t
         temporarily unlocked until the condition is notified. Upon
         notification, [mutex] is re-locked before [wait] returns and
         the thread's activity is resumed. When the awaited condition
-        is notified, the value parameter passed to [notify] is
+        is notified, the value parameter passed to [signal] is
         returned. *)
 
 val signal : 'a t -> 'a -> unit
@@ -56,7 +53,7 @@ val signal : 'a t -> 'a -> unit
         single waiting thread will be awoken and will receive the
         notification value which will be returned from [wait]. Note
         that condition notification is not "sticky", i.e. if there is
-        no waiter when [notify] is called, the notification will be
+        no waiter when [signal] is called, the notification will be
         missed and the value discarded. *)
 
 val broadcast : 'a t -> 'a -> unit
