@@ -135,6 +135,8 @@ sig
   val devpoll : t
   val port : t
 
+  val equal : t -> t -> bool
+
   val pp : Format.formatter -> t -> unit
 end
 
@@ -145,6 +147,9 @@ end
 class libev : ?backend:Ev_backend.t -> unit -> object
   inherit t
 
+  method backend : Ev_backend.t
+    (** The backend picked by libev. *)
+
   val loop : ev_loop
     (** The libev loop used for this engine. *)
 
@@ -208,6 +213,7 @@ sig
   class libev_1 : object
     inherit t
     val loop : ev_loop
+    method backend : Ev_backend.t
     method loop : ev_loop
   end
   [@@ocaml.deprecated
@@ -222,6 +228,7 @@ sig
   class libev_2 : ?backend:Ev_backend.t -> unit -> object
     inherit t
     val loop : ev_loop
+    method backend : Ev_backend.t
     method loop : ev_loop
   end
   [@@ocaml.deprecated
