@@ -8,9 +8,7 @@
    ("deprecated"), and create a local, non-deprecated alias for
    [Lwt_sequence] that can be referred to by the rest of the code in this
    module without triggering any more warnings. *)
-[@@@ocaml.warning "-3"]
 module Lwt_sequence = Lwt_sequence
-[@@@ocaml.warning "+3"]
 
 open Lwt.Infix
 
@@ -161,12 +159,11 @@ external start_job : 'a job -> async_method -> bool = "lwt_unix_start_job"
 (* Starts the given job with given parameters. It returns [true]
    if the job is already terminated. *)
 
-[@@@ocaml.warning "-3"]
 external check_job : 'a job -> int -> bool = "lwt_unix_check_job" "noalloc"
 (* Check whether that a job has terminated or not. If it has not
    yet terminated, it is marked so it will send a notification
    when it finishes. *)
-[@@@ocaml.warning "+3"]
+[@@ocaml.warning "-3"]
 
 (* For all running job, a waiter and a function to abort it. *)
 let jobs = Lwt_sequence.create ()
@@ -228,11 +225,10 @@ let choose_async_method = function
     | Some am -> am
     | None -> !default_async_method_var
 
-[@@@ocaml.warning "-16"]
 let execute_job ?async_method ~job ~result ~free =
   let async_method = choose_async_method async_method in
   run_job_aux async_method job (fun job -> let x = wrap_result result job in free job; x)
-[@@@ocaml.warning "+16"]
+[@@ocaml.warning "-16"]
 
 external self_result : 'a job -> 'a = "lwt_unix_self_result"
 (* returns the result of a job using the [result] field of the C
@@ -304,9 +300,8 @@ type file_descr = {
   (* Hooks to call when the file descriptor becomes writable. *)
 }
 
-[@@@ocaml.warning "-3"]
 external is_socket : Unix.file_descr -> bool = "lwt_unix_is_socket" "noalloc"
-[@@@ocaml.warning "+3"]
+[@@ocaml.warning "-3"]
 
 external guess_blocking_job : Unix.file_descr -> bool job = "lwt_unix_guess_blocking_job"
 
@@ -1034,7 +1029,7 @@ let file_exists name =
     (fun e ->
        match e with
        | Unix.Unix_error _ -> Lwt.return_false
-       | _ -> Lwt.reraise e) [@ocaml.warning "-4"]
+       | _ -> Lwt.reraise e)
 
 external utimes_job : string -> float -> float -> unit job =
   "lwt_unix_utimes_job"
@@ -1140,7 +1135,7 @@ struct
       (fun e ->
          match e with
          | Unix.Unix_error _ -> Lwt.return_false
-         | _ -> Lwt.reraise e) [@ocaml.warning "-4"]
+         | _ -> Lwt.reraise e)
 
 end
 
