@@ -465,10 +465,11 @@ failure:
   uerror("socketpair", Nothing);
 }
 
-static int socket_domain_table[] = {PF_UNIX, PF_INET, PF_INET6};
+static const int socket_domain_table[] =
+  {PF_UNIX, PF_INET, PF_INET6};
 
-static int socket_type_table[] = {SOCK_STREAM, SOCK_DGRAM, SOCK_RAW,
-                                  SOCK_SEQPACKET};
+static const int socket_type_table[] =
+  {SOCK_STREAM, SOCK_DGRAM, SOCK_RAW, SOCK_SEQPACKET};
 
 CAMLprim value lwt_unix_socketpair_stub(value cloexec, value domain, value type,
                                         value protocol) {
