@@ -14,6 +14,7 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
+#include "lwt_unix.h"
 #include "unix_recv_send_utils.h"
 
 value lwt_unix_bytes_recv(value fd, value buf, value ofs, value len,
@@ -22,7 +23,7 @@ value lwt_unix_bytes_recv(value fd, value buf, value ofs, value len,
     int ret;
     ret =
         recv(Int_val(fd), (char *)Caml_ba_array_val(buf)->data + Long_val(ofs),
-             Long_val(len), caml_convert_flag_list(flags, msg_flag_table));
+             Long_val(len), lwt_convert_flag_list(flags, msg_flag_table));
     if (ret == -1) uerror("recv", Nothing);
     return Val_int(ret);
 }
