@@ -16,6 +16,7 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
+#include "lwt_unix.h"
 #include "unix_recv_send_utils.h"
 
 value lwt_unix_bytes_recvfrom(value fd, value buf, value ofs, value len,
@@ -28,7 +29,7 @@ value lwt_unix_bytes_recvfrom(value fd, value buf, value ofs, value len,
     socklen_t addr_len;
     addr_len = sizeof(addr);
     ret = recvfrom(Int_val(fd), (char *)Caml_ba_data_val(buf) + Long_val(ofs),
-                   Long_val(len), caml_convert_flag_list(flags, msg_flag_table),
+                   Long_val(len), lwt_convert_flag_list(flags, msg_flag_table),
                    &addr.s_gen, &addr_len);
     if (ret == -1) uerror("recvfrom", Nothing);
     address = alloc_sockaddr(&addr, addr_len, -1);
