@@ -15,6 +15,7 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
+#include "lwt_unix.h"
 #include "unix_recv_send_utils.h"
 
 value lwt_unix_bytes_sendto(value fd, value buf, value ofs, value len,
@@ -25,7 +26,7 @@ value lwt_unix_bytes_sendto(value fd, value buf, value ofs, value len,
     int ret;
     get_sockaddr(dest, &addr, &addr_len);
     ret = sendto(Int_val(fd), (char *)Caml_ba_data_val(buf) + Long_val(ofs),
-                 Long_val(len), caml_convert_flag_list(flags, msg_flag_table),
+                 Long_val(len), lwt_convert_flag_list(flags, msg_flag_table),
                  &addr.s_gen, addr_len);
     if (ret == -1) uerror("send", Nothing);
     return Val_int(ret);
