@@ -13,13 +13,14 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
+#include "lwt_unix.h"
 #include "unix_recv_send_utils.h"
 
 value lwt_unix_recv(value fd, value buf, value ofs, value len, value flags)
 {
     int ret;
     ret = recv(Int_val(fd), &Byte(String_val(buf), Long_val(ofs)),
-               Long_val(len), caml_convert_flag_list(flags, msg_flag_table));
+               Long_val(len), lwt_convert_flag_list(flags, msg_flag_table));
     if (ret == -1) uerror("recv", Nothing);
     return Val_int(ret);
 }
