@@ -16,7 +16,7 @@ let suite = suite "lwt_pool" [
   end;
 
   test "creator exception" begin fun () ->
-    let gen = fun () -> Lwt.fail Dummy_error in
+    let gen = fun () -> raise Dummy_error in
     let p = Lwt_pool.create 1 gen in
     let u = Lwt_pool.use p (fun _ -> Lwt.return 0) in
     Lwt.return (Lwt.state u = Lwt.Fail Dummy_error)
@@ -42,7 +42,7 @@ let suite = suite "lwt_pool" [
   test "validation exceptions are propagated to users" begin fun () ->
     let c = Lwt_condition.create () in
     let gen = (fun () -> let l = ref 0 in Lwt.return l) in
-    let v l = if !l = 0 then Lwt.return_true else Lwt.fail Dummy_error in
+    let v l = if !l = 0 then Lwt.return_true else raise Dummy_error in
     let p = Lwt_pool.create 1 ~validate:v gen in
     let u1 = Lwt_pool.use p (fun l -> l := 1; Lwt_condition.wait c) in
     let u2 = Lwt_pool.use p (fun l -> Lwt.return !l) in
@@ -106,7 +106,7 @@ let suite = suite "lwt_pool" [
   test "waiter are notified on replacement" begin fun () ->
     let c = Lwt_condition.create () in
     let gen = (fun () -> let l = ref 0 in Lwt.return l) in
-    let v l = if !l = 0 then Lwt.return_true else Lwt.fail Dummy_error in
+    let v l = if !l = 0 then Lwt.return_true else raise Dummy_error in
     let p = Lwt_pool.create 1 ~validate:v gen in
     let u1 = Lwt_pool.use p (fun l -> l := 1; Lwt_condition.wait c) in
     let u2 = Lwt_pool.use p (fun l -> Lwt.return !l) in
@@ -128,9 +128,9 @@ let suite = suite "lwt_pool" [
       if !k then
         let l = ref 0 in Lwt.return l
       else
-        Lwt.fail Dummy_error
+        raise Dummy_error
     in
-    let v l = if !l = 0 then Lwt.return_true else Lwt.fail Dummy_error in
+    let v l = if !l = 0 then Lwt.return_true else raise Dummy_error in
     let p = Lwt_pool.create 1 ~validate:v gen in
     let u1 = Lwt_pool.use p (fun l -> l := 1; k:= false; Lwt_condition.wait c) in
     let u2 = Lwt_pool.use p (fun l -> Lwt.return !l) in
@@ -156,7 +156,7 @@ let suite = suite "lwt_pool" [
     let cond = Lwt_condition.create() in
     let p = Lwt_pool.create 1 ~validate:v ~check:c gen in
     let _ = Lwt_pool.use p (fun l -> l := 1; Lwt_condition.wait cond) in
-    let _ = Lwt_pool.use p (fun l -> l := 2; Lwt.fail Dummy_error) in
+    let _ = Lwt_pool.use p (fun l -> l := 2; raise Dummy_error) in
     let u3 = Lwt_pool.use p (fun l -> Lwt.return !l) in
     let () = Lwt_condition.signal cond "done" in
     Lwt.bind u3 (fun v ->
@@ -169,7 +169,7 @@ let suite = suite "lwt_pool" [
     let p = Lwt_pool.create 1 gen in
     let _ = Lwt_pool.use p (fun l ->
       Lwt.bind (Lwt_condition.wait cond)
-        (fun _ -> l:= 1; Lwt.fail Dummy_error)) in
+        (fun _ -> l:= 1; raise Dummy_error)) in
     let u2 = Lwt_pool.use p (fun l -> Lwt.return !l) in
     let () = Lwt_condition.signal cond "done" in
     Lwt.bind u2 (fun v ->
