@@ -35,7 +35,7 @@ let suite = suite "Lwt_unix sleep and timeout" [
           | Lwt_unix.Timeout ->
             let check = cmp_elapsed_time "timeout" start_time duration in
             Lwt.return check
-          | exn -> Lwt.fail exn
+          | exn -> Lwt.reraise exn
         )
     end;
 
@@ -61,7 +61,7 @@ let suite = suite "Lwt_unix sleep and timeout" [
             let check =
               cmp_elapsed_time "with_timeout : timeout" start_time duration in
             Lwt.return check
-          | exn -> Lwt.fail exn
+          | exn -> Lwt.reraise exn
         )
     end;
 
